import { TimerType } from "./api.js";
const START = {
    [TimerType.ONCE]: setTimeout,
    [TimerType.INTERVAL]: setInterval,
    [TimerType.IMMEDIATE]: typeof setImmediate === "function"
        ? setImmediate
        : (x) => setTimeout(x, 0),
};
const CANCEL = {
    [TimerType.ONCE]: clearTimeout,
    [TimerType.INTERVAL]: clearInterval,
    [TimerType.IMMEDIATE]: typeof clearImmediate === "function" ? clearImmediate : clearTimeout,
};
export class WasmTimers {
    constructor() {
        this.listeners = {};
        this.currEvent = null;
        this.currDataTransfer = null;
    }
    async init(parent) {
        this.parent = parent;
        return true;
    }
    getImports() {
        return {
            _schedule: (listenerID, interval, kind) => {
                const handler = () => this.parent.exports._timer_callback(listenerID, kind);
                const timeoutID = START[kind].call(null, handler, interval);
                this.listeners[listenerID] = {
                    listener: listenerID,
                    timeout: timeoutID,
                    kind,
                };
            },
            _cancel: (listenerID) => {
                const listener = this.listeners[listenerID];
                if (listener) {
                    CANCEL[listener.kind].call(null, listenerID);
                    delete this.listeners[listenerID];
                }
            },
        };
    }
}
